# IOTile Test
A python package for mocking and testing iotile related devices.

## Installation

```
pip install iotile-test
```

## Copyright and license
This code is released under the terms of the LGPL-v3 license.  See LICENSE.md
